@@ -5,11 +5,17 @@ import os
 import time
 from tools_hjh.ThreadPool import ThreadPool
 
+    
+def main():
+    url = 'https://data.elsbbus.com/list.php?name=d9890e5f8eb6cce4014cffc01f008656'
+    head = requests.head(url)
+    print(head.headers)
+
 
 class HttpRequest:
     """ 用户向网站提出请求的类 """
 
-    def connect(self, url, headers=None, data=None, proxies=None):
+    def connect(self, url, headers=None, data=None, proxies=None, encoding='UTF-8'):
         """ 发出get或post请求, 返回状态码 """
         self.url = url.strip()
         self.headers = headers
@@ -21,7 +27,7 @@ class HttpRequest:
                 self.response = requests.get(url, headers=headers, proxies=self.proxies, stream=True, allow_redirects=True)
             else:
                 self.response = requests.post(url, headers=headers, data=data, proxies=self.proxies, stream=True, allow_redirects=True)
-            self.response.encoding = 'UTF-8'
+            self.response.encoding = encoding
         except:
             pass
             
@@ -104,14 +110,14 @@ class HttpRequest:
     
     def __del__(self):
         self.close()
-        
+            
         
 class httptools():
 
     @staticmethod
-    def getText(url, headers=None, data=None, proxies=None):
+    def getText(url, headers=None, data=None, proxies=None, encoding='UTF-8'):
         req = HttpRequest()
-        req.connect(url, headers, data, proxies)
+        req.connect(url, headers, data, proxies, encoding=encoding)
         text = req.getText()
         req.close()
         return text
@@ -142,7 +148,7 @@ class httptools():
         return size
     
     @staticmethod
-    def downloadM3u8(url, dstfile, headers=None, data=None, proxies=None, maxRetryCount=5, nowRetryCount=0, minSize=1024, theadnum=32, maxFailRate=0.015):
+    def downloadM3U8(url, dstfile, headers=None, data=None, proxies=None, maxRetryCount=5, nowRetryCount=0, minSize=1024, theadnum=32, maxFailRate=0.015):
         url = httptools.getLastM3u8(url, headers, data, proxies)
         # 获取上下文
         page = httptools.getText(url, headers, data, proxies)
@@ -218,7 +224,11 @@ class httptools():
         return size
     
     @staticmethod
-    def getLastM3u8(url, headers=None, data=None, proxies=None):
+    def downloadM3u8(url, dstfile, headers=None, data=None, proxies=None, maxRetryCount=5, nowRetryCount=0, minSize=1024, theadnum=32, maxFailRate=0.015):
+        httptools.downloadM3U8(url, dstfile, headers=headers, data=data, proxies=proxies, maxRetryCount=maxRetryCount, nowRetryCount=nowRetryCount, minSize=minSize, theadnum=theadnum, maxFailRate=maxFailRate)
+    
+    @staticmethod
+    def getLastM3U8(url, headers=None, data=None, proxies=None):
         urlSplits = url.split('/')
         urlHead = urlSplits[0] + '//' + urlSplits[2]
         urlPath = url.rsplit('/', 1)[0] + '/'
@@ -243,7 +253,7 @@ class httptools():
         return size
     
     @staticmethod
-    def getSizeM3u8(url, headers=None, data=None, proxies=None):
+    def getSizeM3U8(url, headers=None, data=None, proxies=None):
         tpSaveSize = ThreadPool(128)
         fileSizes = []
         page = httptools.getText(url, headers, data, proxies)
@@ -305,4 +315,14 @@ class httptools():
         key = key.encode('utf-8')
         aes = AES.new(key, mode)
         return aes.decrypt(b)
+    
+    @staticmethod
+    def N_m3u8DL_CLI(url, dstfile, theadnum=32, exePath='N_m3u8DL-CLI'):
+        workDir = os.path.abspath(os.path.dirname(__file__)) + '/' + dstfile.rsplit('/', 1)[0]
+        dstfile = dstfile.split('/')[-1]
+        cmd = exePath + ' --enableDelAfterDone --workDir ' + workDir + ' --saveName ' + dstfile + ' --maxThreads ' + str(theadnum) + ' ' + url
+        os.popen(cmd)
 
+
+if __name__ == '__main__':
+    main()
